@@ -22,16 +22,13 @@ var_interactions <- function(object, ...) {
 #' @export
 var_interactions.data.frame <- function(object, ...) {
   parTable <- removeInteractionVariances(fillColsParTable(object))
-  intTermVarRows <- parTable$lhs == parTable$rhs &
-    grepl(":", parTable$lhs) & parTable$op == "~~"
-  intTermCovRows <- parTable$lhs != parTable$lhs & parTable$op == "~~" &
-    (grepl(":", parTable$lhs) | grepl(":", parTable$rhs))
-  parTable <- parTable[!(intTermVarRows | intTermCovRows), ]
 
   intTerms <- unique(parTable[grepl(":", parTable$rhs) &
                      parTable$op == "~", "rhs"])
 
-  for (i in seq_len(length(intTerms))) {
+  getLabel <- \(x, y) sprintf("%s~~%s", x, y)
+
+  for (intTerm in intTerms) {
     # interaction term = XZ
     # TO DO:
     #   I should also add covariances between X:Z and the other exogenous
@@ -39,21 +36,30 @@ var_interactions.data.frame <- function(object, ...) {
     #   Let Y denote the other exogenous variables, and xz denote the variables in
     #   the interaction term
     #   S(X:Z, Y) = S(X:Z, xz) %*% inv(S(xz, xz)) %*% S(xz, Y) ??
-    XZ    <- stringr::str_split_fixed(intTerms[[i]], ":", 2)
-    muX   <- getMean(XZ[[1]], parTable)
-    muZ   <- getMean(XZ[[2]], parTable)
-    varX  <- calcCovParTable(XZ[[1]], XZ[[1]], parTable)
-    varZ  <- calcCovParTable(XZ[[2]], XZ[[2]], parTable)
-    covXZ <- calcCovParTable(XZ[[1]], XZ[[2]], parTable)
+    XZ   <- stringr::str_split_fixed(intTerm, ":", 2)
+    X    <- XZ[[1]]
+    Z    <- XZ[[2]]
+
+    muX  <- getMean(X, parTable)
+    muZ  <- getMean(Z, parTable)
+
+    lhs  <- c(X, Z, X)
+    rhs  <- c(X, Z, Z)
+
+    covs  <- calcCovParTable(lhs, rhs, parTable)
+    varX  <- covs[[getLabel(X, X)]]
+    varZ  <- covs[[getLabel(Z, Z)]]
+    covXZ <- covs[[getLabel(X, Z)]]
+
     varXZ <- varX * muZ ^ 2 + varZ * muX ^ 2 +
       2 * muX * muZ * covXZ + varX * varZ + covXZ ^ 2
     # needed if mu != 0, but not sure if this is completely correct
     # when X or Z is endogenous
     covX_XZ <- varX * muZ + muX * covXZ
     covZ_XZ <- varZ * muX + muZ * covXZ
-    newRow <- data.frame(lhs = c(intTerms[[i]], XZ[[1]], XZ[[2]]),
+    newRow <- data.frame(lhs = c(intTerm, XZ[[1]], XZ[[2]]),
                          op = rep("~~", 3),
-                         rhs = rep(intTerms[[i]], 3),
+                         rhs = rep(intTerm, 3),
                          label = "",
                          est = c(varXZ, covX_XZ, covZ_XZ),
                          std.error = NA, z.value = NA, p.value = NA,
@@ -106,26 +112,19 @@ standardized_estimates.data.frame <- function(object, intercepts = FALSE, ...) {
   indsLVs  <- getIndsLVs(parTable, lVs)
   allInds  <- unique(unlist(indsLVs))
 
-  variances <- vector("list", length = length(allInds) + length(lVs) +
-                      length(intTerms))
-  names(variances) <- c(allInds, lVs, intTerms)
-
   # get variances
-  for (x in allInds) {
-    variances[[x]] <- calcCovParTable(x, x, parTable,
-                                      measurement.model = TRUE)
-  }
-  for (lV in lVs) {
-    variances[[lV]] <- calcCovParTable(lV, lV, parTable,
-                                       measurement.model = FALSE)
-  }
-  for (xz in intTerms) {
-    variances[[xz]] <- parTable[parTable$lhs == xz &
-                                parTable$rhs == xz &
-                                parTable$op == "~~", "est"]
+  variancesInds <- calcVarParTable(allInds, parTable, measurement.model = TRUE)
+  variancesLVs  <- calcVarParTable(lVs, parTable, measurement.model = FALSE)
+  variancesIntTerms <- structure(numeric(length(intTerms)), names = intTerms)
 
+  for (xz in intTerms) {
+    variancesIntTerms[[xz]] <- parTable[parTable$lhs == xz & 
+                                        parTable$rhs == xz &
+                                        parTable$op == "~~", "est"]
   }
 
+  variances <- c(variancesInds, variancesLVs, variancesIntTerms)
+
   # Factor Loadings
   lambda     <- NULL
   selectRows <- NULL
@@ -151,7 +150,7 @@ standardized_estimates.data.frame <- function(object, intercepts = FALSE, ...) {
     selectStrucExprsEta <- selectStrucExprs & parTable$lhs == eta
     structExprsEta      <- parTable[selectStrucExprsEta, ]
 
-    for (xi in structExprsEta$rhs) {
+    for (xi in structExprsEta$rhs) { # xi can be an interaction term
       selectRows  <- selectStrucExprsEta & parTable$rhs == xi
       scalingCoef <- sqrt(variances[[xi]]) / sqrt(variances[[eta]])
       gamma       <- parTable[selectRows, selectCols]
@@ -182,11 +181,9 @@ standardized_estimates.data.frame <- function(object, intercepts = FALSE, ...) {
   selectRows <- NULL
   residual   <- NULL
 
-  # TODO: Rescale Residual Covariances!?
   for (eta in etas) {
     selectRows <- parTable$lhs == eta & parTable$op == "~~" & parTable$rhs == eta
     residual   <- parTable[selectRows, selectCols]
-    projected  <- calcCovParTable(eta, eta, parTable) - residual
 
     parTable[selectRows, selectCols] <- residual / variances[[eta]]
   }
@@ -208,13 +205,34 @@ standardized_estimates.data.frame <- function(object, intercepts = FALSE, ...) {
                            parTable$rhs == xz, "est"]
     gamma      <- parTable[selectRows, selectCols]
 
-    parTable[selectRows, selectCols] <- gamma / sqrt(varXZ)
+    parTable[selectRows, selectCols] <- gamma / sqrt(varXZ) # unstandardizing, since varXZ != 1 | cov(X, Z) != 0
+  }
+
+  # recalculate custom parameters
+  constrExprs <- sortConstrExprsFinalPt(parTable)
+  parTable <- parTable[parTable$op != ":=", ]
+
+  for (i in seq_len(NROW(constrExprs))) {
+    row <- constrExprs[i, , drop=FALSE]
+
+    expr      <- parse(text=constrExprs[i, "rhs"])
+    labelList <- parTableLabelsToList(parTable) # must be updated for each iteration
+  
+    oldVal <- row$est
+    newVal <- eval(expr, envir = labelList)
+
+    ratio  <- newVal / oldVal
+    values <- row[ , selectCols]
+   
+    row[, selectCols] <- values * ratio
+
+    parTable <- rbind(parTable, row)
   }
 
   parTable$z.value  <- parTable$est / parTable$std.error
   parTable$p.value  <- 2 * stats::pnorm(-abs(parTable$z.value))
-  parTable$ci.lower <- parTable$est - 1.96 * parTable$std.error
-  parTable$ci.upper <- parTable$est + 1.96 * parTable$std.error
+  parTable$ci.lower <- parTable$est - CI_WIDTH * parTable$std.error
+  parTable$ci.upper <- parTable$est + CI_WIDTH * parTable$std.error
 
   parTable
 }
