@@ -40,9 +40,10 @@ summary.modsem_pi <- function(object,
   }
 
   # Baseline (H0) model
-  if (H0) {
-    est_h0 <- tryCatch(estimate_h0(object, ...), error = \(e) NULL)
+  if (H0) tryCatch({
+    est_h0 <- estimate_h0(object, ...)
     out$nullModel <- est_h0
+
     if (!is.null(est_h0)) {
       # Use compare_fit (modsem generic, which internally uses lavTestLRT/anova for modsem_pi)
       lrt <- compare_fit(object, est_h0)
@@ -50,10 +51,10 @@ summary.modsem_pi <- function(object,
       out$fitH0 <- lavaan::fitMeasures(extract_lavaan(est_h0))
       out$logLikH0 <- lavaan::fitMeasures(extract_lavaan(est_h0), "logl")
     }
-  }
+  }, error = \(e) warning2("Baseline model could not be estimated: ", e$message, immediate. = FALSE))
 
   # R-squared for latent endogenous variables only
-  if (r.squared) {
+  if (r.squared) tryCatch({
     # Get all R2
     r2_all <- modsem_inspect(object, "r2")
     # Get latent variables
@@ -63,12 +64,13 @@ summary.modsem_pi <- function(object,
     endo_lhs <- unique(reg_table$lhs[reg_table$op == "~"])
     endo_lv <- intersect(lv_names, endo_lhs)
     out$r.squared <- r2_all[endo_lv]
+
     if (H0 && !is.null(out$nullModel)) {
       r2_all_H0 <- modsem_inspect(out$nullModel, "r2")
       out$r.squared.H0 <- r2_all_H0[endo_lv]
       out$r.squared.diff <- out$r.squared - out$r.squared.H0
     }
-  }
+  }, error = \(e) warning2("R-squared could not be computed: ", e$message, immediate. = FALSE))
 
   class(out) <- c("summary_modsem_pi", "list")
   out
@@ -83,8 +85,12 @@ print.summary_modsem_pi <- function(x, ...) {
   ci <- x$format$ci
 
   # Compute width for right justification based on lavaan output
-  lavcat <- utils::capture.output(print(x$lavaan))
-  width.out <- max(nchar(lavcat))
+  # lavaan always seems to use a width of 54 characters for the main 
+  # part of the first header, regardless of the widht of the coefficient 
+  # tables... So we don't need to compute it dynamically.
+  width.out <- 54
+  # lavcat <- utils::capture.output(print(x$lavaan))
+  # width.out <- max(nchar(lavcat))
 
   # Helper for left/right align with indent of 2 spaces for names
   align_lavaan <- function(lhs, rhs, width, indent = 2) {
