@@ -5,21 +5,15 @@ evalToken <- function(token, lhs, rhs) {
 
 #' @export
 evalToken.LavOperator <- function(token, lhs, rhs) {
-  if (is.LavToken(rhs)) {
-    rhs <- list(rhs)
-  }
-  if (is.LavToken(lhs)) {
-    lhs <- list(lhs)
-  }
-  if (!is.atomic(lhs)) {
-    if (is.LavOperator(lhs$op)) {
-      stop2("Unexpected operator ", highlightErrorToken(lhs$op))
-    }
-  } else if (!is.atomic(rhs)) {
-    if (is.LavOperator(rhs$op)) {
-      stop2("Unexpected operator ", highlightErrorToken(rhs$op))
-    }
-  }
+  if (is.LavToken(rhs)) rhs <- list(rhs)
+  if (is.LavToken(lhs)) lhs <- list(lhs)
+
+  stopif(!is.atomic(lhs) && is.LavOperator(lhs$op), "Unexpected operator ", 
+         highlightErrorToken(lhs$op))
+
+  stopif(!is.atomic(rhs) && is.LavOperator(rhs$op), "Unexpected operator ", 
+         highlightErrorToken(rhs$op))
+
   list(lhs = lhs, op = token, rhs = rhs)
 }
 
@@ -30,8 +24,34 @@ evalToken.LavToken <- function(token, lhs, rhs) {
 }
 
 
+#' @export
+evalToken.LavName <- function(token, lhs, rhs) {
+  stopif(is.LavToken(rhs), "Unexpected token ", 
+         highlightErrorToken(rhs))
+  stopif(is.LavToken(lhs), "Unexpected token ",
+         highlightErrorToken(lhs))
+  token
+}
+
+
+#' @export
+evalToken.LavNumeric <- function(token, lhs, rhs) {
+  stopif(is.LavToken(rhs), "Unexpected token ", 
+         highlightErrorToken(rhs))
+  stopif(is.LavToken(lhs), "Unexpected token ",
+         highlightErrorToken(lhs))
+  token
+}
+
+
 #' @export
 evalToken.LavAdd <- function(token, lhs, rhs) {
+  if (is.null(rhs)) {
+    stop2("Expected token after `+` ", highlightErrorToken(token))
+  } else if (is.null(lhs)) { 
+    stop2("Expected token before `+` ", highlightErrorToken(token))
+  } 
+  
   if (is.LavToken(rhs)) {
     rhs <- list(rhs)
   }
@@ -109,6 +129,7 @@ evalTokens <- function(syntaxTree) {
   if (is.null(syntaxTree) || length(syntaxTree) == 0) {
     return(NULL)
   }
+
   lhs <- evalTokens(syntaxTree$lhs)
   rhs <- evalTokens(syntaxTree$rhs)
 
