@@ -17,4 +17,8 @@ run <- tryCatch({
   },
   error = function(e) FALSE
 )
-if (run) mplus <- modsem(m1, oneInt, method = "mplus")
+if (run) {
+  mplus <- modsem(m1, oneInt, method = "mplus")
+  print(summary(mplus))
+  plot_interaction(x = "X", z = "Z", y = "Y", xz = "X:Z", vals_z = c(-0.5, 0.5), model = mplus)
+} 
